==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Shape/ShapeRectangleSize/ts/ShapeRectangleSize_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ShapeRectangleSize</name>
    <message>
        <location filename="../ShapeRectangleSize.ui" line="+17"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+19"/>
        <source>&amp;Width:</source>
        <translation>&amp;Šírka:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+30"/>
        <source>&amp;Height:</source>
        <translation>&amp;Výška:</translation>
    </message>
    <message>
        <location line="+30"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="-10"/>
        <source>Angle:</source>
        <translation>Uhol:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>Referenčný bod:</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+101"/>
        <source>Create Polyline</source>
        <translation>Vytvoriť krivku</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeInit.js" line="+2"/>
        <source>Rectangle with &amp;Size</source>
        <translation>Obdĺžnik &amp;s Rozmermi</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw rectangle with position and size</source>
        <translation>Nakreslite obdĺžnik s rozmermi a polohou</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Shape/ShapeRectangleSize/ts/ShapeRectangleSize_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ShapeRectangleSize</name>
    <message>
        <location filename="../ShapeRectangleSize.ui" line="+17"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+19"/>
        <source>&amp;Width:</source>
        <translation>&amp;Šírka (os X):</translation>
    </message>
    <message>
        <location line="+23"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+30"/>
        <source>&amp;Height:</source>
        <translation>&amp;Výška (os Y):</translation>
    </message>
    <message>
        <location line="+30"/>
        <location filename="../ShapeRectangleSizeDialog.ui" line="-10"/>
        <source>Angle:</source>
        <translation>Uhol:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>Referenčný bod:</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeDialog.ui" line="+101"/>
        <source>Create Polyline</source>
        <translation>Vytvoriť krivku</translation>
    </message>
    <message>
        <location filename="../ShapeRectangleSizeInit.js" line="+2"/>
        <source>Rectangle with &amp;Size</source>
        <translation>Obdĺžnik &amp;s Rozmermi</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw rectangle with position and size</source>
        <translation>Nakreslite obdĺžnik s rozmermi a polohou</translation>
    </message>
</context>
</TS>
